#
# spec file for package cabextract
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           cabextract
Version:        1.11
Release:        1.5
Summary:        A Program to Extract Microsoft Cabinet Files
License:        GPL-3.0-or-later
Group:          System/Console
URL:            https://www.cabextract.org.uk/
Source:         https://www.cabextract.org.uk/%{name}-%{version}.tar.gz
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libmspack) >= 0.8

%description
Cabinet (.CAB) files are a form of archive, which Microsoft uses to
distribute their software and things like Windows Font Packs.
cabextract can be used to unpack these files.

%prep
%autosetup

%build
%configure \
  --with-external-libmspack
%make_build

%install
%make_install

%check
%make_build check

%files
%license COPYING
%doc AUTHORS README
%{_bindir}/cabextract
%{_mandir}/man1/cabextract.1%{?ext_man}

%changelog
* Tue Mar  7 2023 Dirk Müller <dmueller@suse.com>
- update to 1.11:
  * Fixed bug in creating directories given in archives, e.g.
    extracting file
* Mon Feb  6 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 1.10
  * Multiple -F filters can be given. cabextract will extract
    files matching any of the filters.
  * cabextract now overwrites symlinks by default. This is to be
    consistent with other archive tools. Use the new -k option for
    the old behaviour of keeping symlinks. This does not affect
    symlinks in the -d dirpath option.
  * New -n option to never overwrite files.
  * New -i option to interactively prompt if you want to overwrite
    files.
* Fri Sep 20 2019 Martin Pluskal <mpluskal@suse.com>
- Modernise spec file
* Fri Sep 20 2019 Berthold Gunreben <azouhr@opensuse.org>
- Update to version 1.9.1
  * Rerelease of 1.9 with some packaging issues fixed
* Wed Nov  7 2018 sbrabec@suse.com
- Update to version 1.9:
  * Fix invisibly wrong results in cabextract -F (1.8 regression).
  * Fix ./configure --with-external-libmspack.
  * Build system cleanup
  * Testsuite available
* Tue Oct 23 2018 sbrabec@suse.com
- Update to version 1.8:
  * Improves ability to extract damaged files with the "-f" option.
  * cabinfo command has been rewritten.
  * If a CAB file has a Quantum-compressed datablock with exactly
    38912 compressed bytes, cabextract will write exactly one byte
    beyond its input buffer.
* Thu Jul 26 2018 sbrabec@suse.com
- Update to version 1.7:
  * Few bug fixes
  * New "--encoding" option
  * Properly handle lowercase conversion for non-ASCII characters.
* Fri Apr 13 2018 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
* Sun Jan 31 2016 mpluskal@suse.com
- Tiny spec file cleanup
* Thu Apr  2 2015 sbrabec@suse.cz
- Update to version 1.6:
  * further UTF-8 fixes
  * sanitize file names
- Add -fno-strict-aliasing for md5.c: 114, 115.
* Fri Feb 20 2015 mpluskal@suse.com
- Use url for source
- New version 1.5:
  * Several crashes and hangs were found by Debian project members
  using the afl tool to generate corrupt cabinet files. These
  crashes and hangs have been fixed.
  * cabextract now replaces bad Unicode characters in filenames
  with the standard Unicode replacement character
  * wince_rename now puts files under the correct installation path
* Sat Dec 20 2014 meissner@suse.com
- build with PIE
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Sat May 21 2011 vlado.paskov@gmail.com
- Version update to 1.4
* Wed Dec 22 2010 andreas.hanke@gmx-topmail.de
- use system libmspack (#660942)
* Sat Jul 24 2010 meissner@suse.de
- updated to version 1.3:
  * Bugs in the MS-ZIP and Quantum decompressors have been fixed. This
    fixes two security vulnerabilites: a segfault when testing a specific
    Quantum archive, and an infinite loop when testing or extracting a
    badly-formed MSZIP archive.
  * MS-ZIP recovery has been improved. You will now get data from within
    a bad block, up to the point it turned bad.
- license changed to GPLv3
* Thu Sep 21 2006 sndirsch@suse.de
- updated to version 1.2:
  * The "-t" archive integrity checking option has been added. This
    was requested by several users. cabextract can unpack cabinet
    files and give you MD5 checksums of the files inside, without
    writing the unpacked files to disk.
  * Large files (more than 2 gigabytes) are now correctly searched
    for cabinet files.
  * A security vulnerability has been fixed. Files compressed with
    the Quantum method, using a window size less than 32768 bytes,
    could cause cabextract to write beyond the end of the window
    and cause a segmentation fault. This fix also permits
    cabextract to unpack this type of cabinet file (of which only
    one has been found in the wild) correctly.
  * The unnecessary GNU source mempcpy.c, which caused compilation
    failures on several systems, was removed.
  * An off-by-one error introduced in 1.1's UTF-8 decoder was
    fixed. Files with UTF-8 filenames can now be extracted. The
    UTF-8 decoder was also upgraded to support the latest
    Unicode characer maps.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sun Jan 23 2005 meissner@suse.de
- use RPM_OPT_FLAGS.
* Tue Oct 26 2004 sndirsch@suse.de
- updated to version 1.1
  * A security vulnerability has been fixed. If the files within a
  cabinet file include "../" in their filenames, this will be
  changed to "xx/", so cabinets cannot access the parent directory
  of where you want to extract them. (Bug #47537)
  * cabextract should now compile cleanly on AIX and Cygwin
* Mon Mar 15 2004 sndirsch@suse.de
- updated to version 1.0
  Changes since 0.6:
  * The cabextract source has been refactored and rewritten into a
  portable, extensible, robust library called libmspack. Now
  cabextract is just a UNIX-specialised command line application using
  the OS-agnostic libmspack CAB decompressor. Any developers who were
  considering using cabextract in their own software should now look
  at libmspack first.
  * Many bugs in the decompressers were squashed after
  refactoring. More than three gigabytes of real CAB files from the
  wild were used in testing. Corrupt cabinets that crashed cabextract
  0.6 are now correctly reported as corrupt, without crashing.
  * cabextract now alerts you if you try and use it to unpack
  InstallShield cabinet files. This is the number one FAQ saver.
  * cabextract no longer gets "/" and "\" mixed up.
  * cabextract now ignores cabinet files listed on the command line
  that have already been used as part of a multi-part set. You can now
  type cabextract *.cab on a big multi-part set, cabextract will not
  extract all the files several times over.
  * cabextract now lists files with the same filenames it would use if
  it were extracting them. This includes always showing UNIX directory
  separators in the listing.
  * cabextract now correctly lowercases cabinet files with Unicode
  filenames.
  * cabextract has the new --filter, --single and --pipe options.
  * The cabextract package now includes experimental wince_info and
  wince_rename scripts.
  * The definition of Microsoft cabinet files in doc/magic has been
  fixed, and a definition of Windows CE install cabinet header files
  has also been added.
* Sun Jan 11 2004 adrian@suse.de
- add %%defattr
* Mon Jan 27 2003 sndirsch@suse.de
- created package (revival, Bug #23142)
